import { compact } from '../../util/array.js';
import { dirname, join, relative } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern } from '../../util/protocols.js';
export const NAME = 'Playwright';
export const ENABLERS = ['@playwright/test'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const ENTRY_FILE_PATTERNS = ['**/*.@(spec|test).?(c|m)[jt]s?(x)'];
export const CONFIG_FILE_PATTERNS = ['playwright.config.{js,ts}'];
const findProjectDependencies = (cwd, configFilePath, config) => {
    const dir = relative(cwd, config.testDir ? join(dirname(configFilePath), config.testDir) : dirname(configFilePath));
    const entryPatterns = (config.testMatch ? [config.testMatch] : ENTRY_FILE_PATTERNS).flatMap(pattern => [pattern].flat().flatMap(pattern => (typeof pattern === 'string' ? toEntryPattern(join(dir, pattern)) : [])));
    return entryPatterns;
};
const findPlaywrightDependencies = async (configFilePath, { cwd }) => {
    const config = await load(configFilePath);
    const projects = config.projects ? config.projects : [config];
    return compact(projects.flatMap(project => findProjectDependencies(cwd, configFilePath, project)));
};
export const findDependencies = timerify(findPlaywrightDependencies);
